@@ -7,7 +7,7 @@ Attean::API - Utility package for loading all Attean role packages.
 
 =head1 VERSION
 
-This document describes Attean::API version 0.021
+This document describes Attean::API version 0.023
 
 =head1 SYNOPSIS
 
@@ -25,15 +25,15 @@ in the Attean::API namespace.
 
 =cut
 
-package Attean::API::ResultOrTerm 0.021 {
+package Attean::API::ResultOrTerm 0.023 {
 	use Moo::Role;
 }
 
-package Attean::API::BlankOrIRI 0.021 {
+package Attean::API::BlankOrIRI 0.023 {
 	use Moo::Role;
 }
 
-package Attean::API::TermOrVariable 0.021 {
+package Attean::API::TermOrVariable 0.023 {
 	use Scalar::Util qw(blessed);
 	use Sub::Install;
 	use Sub::Util qw(set_subname);
@@ -46,6 +46,11 @@ package Attean::API::TermOrVariable 0.021 {
 		my ($a, $b)	= @_;
 		return ($a->as_string eq $b->as_string);
 	}
+
+	sub is_bound {
+	  my $self = shift;
+	  return (! $self->does('Attean::API::Variable'));
+	}
 	
 	sub apply_binding {
 		my $self	= shift;
@@ -83,12 +88,12 @@ package Attean::API::TermOrVariable 0.021 {
 	}
 }
 
-package Attean::Mapper 0.021 {
+package Attean::Mapper 0.023 {
 	use Moo::Role;
 	requires 'map'; # my $that = $object->map($this)
 }
 
-package Attean::API::Variable 0.021 {
+package Attean::API::Variable 0.023 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 
@@ -115,7 +120,7 @@ Returns a string representation of the variable.'
 	
 }
 
-package Attean::API::CanonicalizingBindingSet 0.021 {
+package Attean::API::CanonicalizingBindingSet 0.023 {
 	use Attean::RDF;
 
 	use Moo::Role;
@@ -212,7 +217,7 @@ package Attean::API::CanonicalizingBindingSet 0.021 {
 	}
 }
 
-package Attean::API 0.021 {
+package Attean::API 0.023 {
 	use Attean::API::Term;
 	use Attean::API::Store;
 	use Attean::API::Model;
@@ -250,7 +255,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2018 Gregory Todd Williams.
+Copyright (c) 2014--2019 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
