@@ -7,7 +7,7 @@ Attean::Triple - RDF Triples
 
 =head1 VERSION
 
-This document describes Attean::Triple version 0.015
+This document describes Attean::Triple version 0.023
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ This role consumes L<Attean::API::Triple>.
 
 =cut
 
-package Attean::TriplePattern 0.015 {
+package Attean::TriplePattern 0.023 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Attean::RDF;
@@ -53,16 +53,12 @@ package Attean::TriplePattern 0.015 {
 	sub as_quadpattern {
 		my $self	= shift;
 		my $graph	= shift;
-		return Attean::QuadPattern->new(
-			subject		=> $self->subject,
-			predicate	=> $self->predicate,
-			object		=> $self->object,
-			graph		=> $graph,
-		);
+		# TODO: deprecate this in favor of as_quad_pattern() provided by Attean::API::TriplePattern
+		return $self->as_quad_pattern($graph);
 	}
 }
 
-package Attean::Triple 0.015 {
+package Attean::Triple 0.023 {
 	use Moo;
 	use Attean::API::Binding;
 	
@@ -96,7 +92,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -104,7 +100,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2019 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
